// 
// File:        ArrayTestDriver.java
// Copyright:   (c) 2001 The Regents of the University of California
// Release:     $Name: release-0-9-8 $
// Revision:    @(#) $Revision: 1.15.2.1 $
// Date:        $Date: 2004/08/11 21:53:00 $
// Description: array regression test case for Java calling other languages
// 

/**
 * The following class runs the array regression test cases for Java.
 */
public class ArrayTestDriver {
  private final static int FAIL        = 0;
  private final static int XFAIL       = 1;
  private final static int PASS        = 2;
  private final static int XPASS       = 3;
  private final static int UNSUPPORTED = 4;

  private final static String[] s_results = {
    "FAIL",
    "XFAIL",
    "PASS",
    "XPASS",
    "UNSUPPORTED"
  };

  private final static int ONE_D_SIZE = 345;
  private final static int TEST_DIM1 = 13;
  private final static int TEST_DIM2 = 16;

  private static int s_part = 0;
  private static int s_result = PASS;

  /**
   * Check the results of the test case.
   */
  private static void check(int expected, boolean pass, String test) {
    System.out.println("PART " + String.valueOf(++s_part));
    System.out.println("COMMENT " + test);
    System.out.print("RESULT " + String.valueOf(s_part) + " ");

    if (expected == UNSUPPORTED) {
      System.out.println(s_results[expected]);
      if (s_result == PASS) {
        s_result = XFAIL;
      }
    } else if (expected == PASS) {
      System.out.println(s_results[pass ? PASS : FAIL]);
      if (!pass) {
        s_result = FAIL;
      }
    } else if (expected == XFAIL) {
      System.out.println(s_results[pass ? XPASS : XFAIL]);
      if (pass) {
        s_result = FAIL;
      } else if (s_result > XFAIL) {
        s_result = XFAIL;
      }
    }
  }


  /**
   * The main test driver takes no command-line arguments and runs the
   * regression tests.
   */
  public static void main(String args[]) {
    try {

      /*
       * Begin the test
       */

      System.out.println("NPARTS -1");

      s_part   = 0;
      s_result = PASS;

      /*
       * Boolean array tests
       */

      /*if (true) {
	    sidl.Integer.Array1 array = ArrayTest.ArrayOps.createInt(ONE_D_SIZE);

	int i = array._get(1);
	System.out.println(i);
	array._destroy();
	}*/
	if (true) {
	sidl.Boolean.Array1 array = ArrayTest.ArrayOps.createBool(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createBool: (array != null)");

        check(PASS,
              (ArrayTest.ArrayOps.checkBool(array) == true),
             "createBool: (ArrayTest.ArrayOps.checkBool(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseBool(array, true) == true),
             "createBool: " + 
             "(ArrayTest.ArrayOps.reverseBool(array, true) == true)");

        check(PASS, (array._length(0) == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        System.out.println("Correct" + ONE_D_SIZE + " returned " + array._length(0));

        ArrayTest.ArrayOps.makeBool(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkBool(array) == true),
             "makeBool218: (ArrayTest.ArrayOps.checkBool(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseBool(array, false) == true),
             "makeBool218: " + 
             "(ArrayTest.ArrayOps.reverseBool(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkBool(array) == false),
             "makeBool218: (ArrayTest.ArrayOps.checkBool(array) == false)");

        ArrayTest.ArrayOps.makeBool(9, array);
        check(PASS,
              (ArrayTest.ArrayOps.reverseBool(array, false) == true),
             "makeBool9: " +
             "(ArrayTest.ArrayOps.reverseBool(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkBool(array) == true),
             "makeBool9: (ArrayTest.ArrayOps.checkBool(array) == true)");

      }

      /*
       * Character array tests
       */

      if (true) {
        sidl.Character.Array1 array = ArrayTest.ArrayOps.createChar(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createChar: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkChar(array) == true),
             "createChar: (ArrayTest.ArrayOps.checkChar(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseChar(array, true) == true),
             "createChar: " +
             "(ArrayTest.ArrayOps.reverseChar(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");

        ArrayTest.ArrayOps.makeChar(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkChar(array) == true),
             "makeChar: (ArrayTest.ArrayOps.checkChar(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseChar(array, false) == true),
             "makeChar: " +
             "(ArrayTest.ArrayOps.reverseChar(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkChar(array) == false),
             "makeChar: (ArrayTest.ArrayOps.checkChar(array) == false)");

      }

      /*
       * Integer array tests
       */

      if (true) {
        sidl.Integer.Array1 array = ArrayTest.ArrayOps.createInt(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createInt: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkInt(array) == true),
             "createInt: (ArrayTest.ArrayOps.checkInt(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseInt(array, true) == true),
             "createInt: (ArrayTest.ArrayOps.reverseInt(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");

        ArrayTest.ArrayOps.makeInt(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkInt(array) == true),
             "makeInt: (ArrayTest.ArrayOps.checkInt(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseInt(array, false) == true),
             "makeInt: (ArrayTest.ArrayOps.reverseInt(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkInt(array) == false),
             "makeInt: (ArrayTest.ArrayOps.checkInt(array) == false)");

      }

      /*
       * Long array tests
       */

      if (true) {
        sidl.Long.Array1 array = ArrayTest.ArrayOps.createLong(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createLong: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkLong(array) == true),
             "createLong: (ArrayTest.ArrayOps.checkLong(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseLong(array, true) == true),
             "createLong: " +
             "(ArrayTest.ArrayOps.reverseLong(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeLong(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkLong(array) == true),
             "makeLong: (ArrayTest.ArrayOps.checkLong(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseLong(array, false) == true),
             "makeLong: " +
             "(ArrayTest.ArrayOps.reverseLong(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkLong(array) == false),
             "makeLong: (ArrayTest.ArrayOps.checkLong(array) == false)");

      }

      /*
       * String array tests
       */

      if (true) {
        sidl.String.Array1 array = ArrayTest.ArrayOps.createString(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createString: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkString(array) == true),
             "createString: (ArrayTest.ArrayOps.checkString(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseString(array, true) == true),
             "createString: " + 
             "(ArrayTest.ArrayOps.reverseString(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeString(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkString(array) == true),
             "makeString: (ArrayTest.ArrayOps.checkString(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseString(array, false) == true),
             "makeString: " +
             "(ArrayTest.ArrayOps.reverseString(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkString(array) == false),
             "makeString: (ArrayTest.ArrayOps.checkString(array) == false)");
     
      }

      /*
       * Double array tests
       */

      if (true) {
        sidl.Double.Array1 array = ArrayTest.ArrayOps.createDouble(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createDouble: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkDouble(array) == true),
             "createDouble: (ArrayTest.ArrayOps.checkDouble(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseDouble(array, true) == true),
             "createDouble: " +
             "(ArrayTest.ArrayOps.reverseDouble(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeDouble(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkDouble(array) == true),
             "makeDouble: (ArrayTest.ArrayOps.checkDouble(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseDouble(array, false) == true),
             "makeDouble: " + 
             "(ArrayTest.ArrayOps.reverseDouble(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkDouble(array) == false),
             "makeDouble: (ArrayTest.ArrayOps.checkDouble(array) == false)");

      }

      /*
       * Float array tests
       */

      if (true) {
        sidl.Float.Array1 array = ArrayTest.ArrayOps.createFloat(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createFloat: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkFloat(array) == true),
             "createFloat: (ArrayTest.ArrayOps.checkFloat(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseFloat(array, true) == true),
             "createFloat: " +
             "(ArrayTest.ArrayOps.reverseFloat(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeFloat(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkFloat(array) == true),
             "makeFloat: (ArrayTest.ArrayOps.checkFloat(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseFloat(array, false) == true),
             "makeFloat: " +
             "(ArrayTest.ArrayOps.reverseFloat(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkFloat(array) == false),
             "makeFloat: (ArrayTest.ArrayOps.checkFloat(array) == false)");

      }

      /*
       * FloatComplex array tests
       */

      if (true) {
        sidl.FloatComplex.Array1 array =
          ArrayTest.ArrayOps.createFcomplex(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createFcomplex: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkFcomplex(array) == true),
             "createFcomplex: " +
             "(ArrayTest.ArrayOps.checkFcomplex(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseFcomplex(array, true) == true),
             "createFcomplex: " +
             "(ArrayTest.ArrayOps.reverseFcomplex(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeFcomplex(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkFcomplex(array) == true),
             "makeFcomplex: (ArrayTest.ArrayOps.checkFcomplex(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseFcomplex(array, false) == true),
             "makeFcomplex: " +
             "(ArrayTest.ArrayOps.reverseFcomplex(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkFcomplex(array) == false),
             "makeFcomplex: " +
             "(ArrayTest.ArrayOps.checkFcomplex(array) == false)");
   
      }

      /*
       * DoubleComplex array tests
       */

      if (true) {
        sidl.DoubleComplex.Array1 array =
          ArrayTest.ArrayOps.createDcomplex(ONE_D_SIZE);
        check(PASS,
              (array != null),
             "createDcomplex: (array != null)");
        check(PASS,
              (ArrayTest.ArrayOps.checkDcomplex(array) == true),
             "createDcomplex: " +
             "(ArrayTest.ArrayOps.checkDcomplex(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseDcomplex(array, true) == true),
             "createDcomplex: " +
             "(ArrayTest.ArrayOps.reverseDcomplex(array, true) == true)");
        check(PASS, (array.length() == ONE_D_SIZE), "ARRAY LENGTH CORRECTLY RETRIEVED");
        ArrayTest.ArrayOps.makeDcomplex(218, array);
        check(PASS,
              (ArrayTest.ArrayOps.checkDcomplex(array) == true),
             "makeDcomplex: (ArrayTest.ArrayOps.checkDcomplex(array) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.reverseDcomplex(array, false) == true),
             "makeDcomplex: " +
             "(ArrayTest.ArrayOps.reverseDcomplex(array, false) == true)");
        check(PASS,
              (ArrayTest.ArrayOps.checkDcomplex(array) == false),
             "makeDcomplex: " +
             "(ArrayTest.ArrayOps.checkDcomplex(array) == false)");
     
      }

      /*
       * Object array tests
       */

      if (true) {
	  ArrayTest.ArrayOps.Array1 array = (ArrayTest.ArrayOps.Array1)ArrayTest.ArrayOps.createObject(10);
	  check(PASS, (array != null), "The Array of Objects is not NULL");
	  check(PASS, (ArrayTest.ArrayOps.checkObject(array) == 10), "Check an array of objects");
          check(PASS, (array.length() == 10), "Correctly retrived length");
	  array.set(5, new ArrayTest.ArrayOps());
	  ArrayTest.ArrayOps recieved = null;
	  recieved = array.get(5);
	  check(PASS, (recieved != null), "Successfully get an object from an Array");
       

	  /*
	   *  Test Object sliced and copied arrays
	   */

	  int[] numElem = {10};
	  int[] stride = {1};
	  ArrayTest.ArrayOps.Array sliced = array._slice(1, numElem, (int[]) null,
	  						 (int[]) stride, (int[]) null);
	  ArrayTest.ArrayOps.Array1 sliced1 = (ArrayTest.ArrayOps.Array1) sliced._dcast();
	  check(PASS, (sliced != null), "The Sliced Array is not NULL");
	  check(PASS, (sliced.get_ior_pointer() == sliced1.get_ior_pointer()), "The cast array is equal to the non cast array"); 
	  
	  check(PASS, (sliced1._get(0) != null), "Sliced array element 0 is not null");
	  sidl.BaseClass testBase = (sidl.BaseClass) sidl.BaseClass._cast(recieved);
	  ArrayTest.ArrayOps testA = (ArrayTest.ArrayOps) ArrayTest.ArrayOps._cast(testBase);
	  check(PASS, (testBase != null), "Element cast to baseClass is not null");
	  check(PASS, (testBase._get_ior() == testA._get_ior()), "Pre cast and post cast elements are equal");  


     }

      /*
       * Create and check two dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array2 array = ArrayTest.ArrayOps.create2Int(TEST_DIM1,
                                                                  TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Int(array) == true),
             "create2Int: " + 
             "(ArrayTest.ArrayOps.check2Int(array) == true)");
        check(PASS, (array.length(0) == TEST_DIM1), "1st Dimension has the correct length");
        check(PASS, (array.length(1) == TEST_DIM2), "2nd Dimension has the correct length");
        
      }

      /*
       * Create and check two dimensional array for double
       */

      if (true) {
        sidl.Double.Array2 array = ArrayTest.ArrayOps.create2Double(TEST_DIM1,
                                                                    TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Double(array) == true),
             "create2Double: " + 
             "(ArrayTest.ArrayOps.check2Double(array) == true)");
        check(PASS, (array.length(0) == TEST_DIM1), "1st Dimension has the correct length");
        check(PASS, (array.length(1) == TEST_DIM2), "2nd Dimension has the correct length");
      }

      /*
       * Create and check two dimensional array for float
       */

      if (true) {
        sidl.Float.Array2 array = ArrayTest.ArrayOps.create2Float(TEST_DIM1,
                                                                  TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Float(array) == true),
             "create2Float: (ArrayTest.ArrayOps.check2Float(array) == true)");
      }

      /*
       * Create and check two dimensional array for double complex
       */

      if (true) {
        sidl.DoubleComplex.Array2 array = ArrayTest.ArrayOps.create2Dcomplex(
                                                         TEST_DIM1, TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Dcomplex(array) == true),
             "create2Dcomplex:" + 
             "(ArrayTest.ArrayOps.check2Dcomplex(array) == true)");
      }

      /*
       * Create and check two dimensional array for float complex
       */

      if (true) {
        sidl.FloatComplex.Array2 array = ArrayTest.ArrayOps.create2Fcomplex(
                                                         TEST_DIM1, TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Fcomplex(array) == true),
             "create2Fcomplex: " +
             "(ArrayTest.ArrayOps.check2Fcomplex(array) == true)");
      }

      /*
       * Create and check three dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array3 array = ArrayTest.ArrayOps.create3Int();
        check(PASS,
              (ArrayTest.ArrayOps.check3Int(array) == true),
             "create3Int: " +
             "(ArrayTest.ArrayOps.check3Int(array) == true)");
      }

      /*
       * Create and check four dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array4 array = ArrayTest.ArrayOps.create4Int();
        check(PASS,
              (ArrayTest.ArrayOps.check4Int(array) == true),
             "create4Int: " +
             "(ArrayTest.ArrayOps.check4Int(array) == true)");
      }

      /*
       * Create and check five dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array5 array = ArrayTest.ArrayOps.create5Int();
        check(PASS,
              (ArrayTest.ArrayOps.check5Int(array) == true),
             "create5Int: " +
             "(ArrayTest.ArrayOps.check5Int(array) == true)");
      }

      /*
       * Create and check six dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array6 array = ArrayTest.ArrayOps.create6Int();
        check(PASS,
              (ArrayTest.ArrayOps.check6Int(array) == true),
             "create6Int: " +
             "(ArrayTest.ArrayOps.check6Int(array) == true)");
      }

      /*
       * Create and check seven dimensional array for integer
       */

      if (true) {
        sidl.Integer.Array7 array = ArrayTest.ArrayOps.create7Int();
        check(PASS,
              (ArrayTest.ArrayOps.check7Int(array) == true),
             "create7Int: " +
             "(ArrayTest.ArrayOps.check7Int(array) == true)");
      }



      /*
       * inout null Boolean array test
       */
      
      if (true) {
	  /*  check(XFAIL, false, "makeInOutBool using null array");
	   */
	  sidl.Boolean.Array1 array = new sidl.Boolean.Array1();
	  ArrayTest.ArrayOps.makeInOutBool(array, 218);
	  check(PASS, 
		(ArrayTest.ArrayOps.checkBool(array) == true),
		"makeInOutBool: (ArrayTest.ArrayOps.checkBool(array) == true)"); 
      }

      /*
       * inout null Character array test
       */
      
      if (true) {	
	  //  check(XFAIL, false, "makeInOutChar using null array");
	  
	  sidl.Character.Array1 array = new sidl.Character.Array1();
	  ArrayTest.ArrayOps.makeInOutChar(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkChar(array) == true),
		"makeInOutChar: (ArrayTest.ArrayOps.checkChar(array) == true)");
	  
      }

      /*
       * inout null Integer array test
       */

      if (true) {	
	  //        check(XFAIL, false, "makeInOutInt using null array");

	  sidl.Integer.Array1 array = new sidl.Integer.Array1();
	  ArrayTest.ArrayOps.makeInOutInt(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkInt(array) == true),
		"makeInOutInt: (ArrayTest.ArrayOps.checkInt(array) == true)");
	
      }

      /*
       * inout null Long array test
       */

      if (true) {
	  //        check(XFAIL, false, "makeInOutLong using null array");
      
	  sidl.Long.Array1 array = new sidl.Long.Array1();
	  ArrayTest.ArrayOps.makeInOutLong(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkLong(array) == true),
		"makeInOutLong: (ArrayTest.ArrayOps.checkLong(array) == true)");
	  
      }

      /*
       * inout null String array test
       */

      if (true) {	
	  //     check(XFAIL, false, "makeInOutString using null array");

	  sidl.String.Array1 array = new sidl.String.Array1();
	  ArrayTest.ArrayOps.makeInOutString(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkString(array) == true),
		"makeInOutString: " + 
		"(ArrayTest.ArrayOps.checkString(array) == true)");

      }

      /*
       * inout null Double array test
       */

      if (true) {
	  //       check(XFAIL, false, "makeInOutDouble using null array");

	  sidl.Double.Array1 array = new sidl.Double.Array1();
	  ArrayTest.ArrayOps.makeInOutDouble(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkDouble(array) == true),
		"makeInOutDouble: " +
		"(ArrayTest.ArrayOps.checkDouble(array) == true)");

      }

      /*
       * inout null Float array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOutFloat using null array");

	  sidl.Float.Array1 array = new sidl.Float.Array1();
	  ArrayTest.ArrayOps.makeInOutFloat(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkFloat(array) == true),
		"makeInOutFloat: (ArrayTest.ArrayOps.checkFloat(array) == true)");

      }

      /*
       * inout null FloatComplex array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOutFloatComplex using null array");

	  sidl.FloatComplex.Array1 array = new sidl.FloatComplex.Array1();
	  ArrayTest.ArrayOps.makeInOutFcomplex(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkFcomplex(array) == true),
		"makeInOutFcomplex: " +
		"(ArrayTest.ArrayOps.checkFcomplex(array) == true)");

      }

      /*
       * inout null DoubleComplex array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOutDoubleComplex using null array");

	  sidl.DoubleComplex.Array1 array = new sidl.DoubleComplex.Array1();
	  ArrayTest.ArrayOps.makeInOutDcomplex(array, 218);
	  check(PASS,
		(ArrayTest.ArrayOps.checkDcomplex(array) == true),
		"makeInOutDcomplex: " +
		"(ArrayTest.ArrayOps.checkDcomplex(array) == true)");

      }

      /*
       * inout null 2D integer array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut2Int using null array");

	  sidl.Integer.Array2 array = new sidl.Integer.Array2();
	  ArrayTest.ArrayOps.makeInOut2Int(array, TEST_DIM1, TEST_DIM2);
	  check(PASS,
		(ArrayTest.ArrayOps.check2Int(array) == true),
		"makeInOut2Int: " +
		"(ArrayTest.ArrayOps.check2Int(array) == true)");

      }

      /*
       * inout null 2D double array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut2Double using null array");

	  sidl.Double.Array2 array = new sidl.Double.Array2();
	  ArrayTest.ArrayOps.makeInOut2Double(array, TEST_DIM1, TEST_DIM2);
	  check(PASS,
		(ArrayTest.ArrayOps.check2Double(array) == true),
		"makeInOut2Double: " +
		"(ArrayTest.ArrayOps.check2Double(array) == true)");
	  
      }

      /*
       * inout null 2D float array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut2Float using null array");

        sidl.Float.Array2 array = new sidl.Float.Array2();
        ArrayTest.ArrayOps.makeInOut2Float(array, TEST_DIM1, TEST_DIM2);
        check(PASS,
              (ArrayTest.ArrayOps.check2Float(array) == true),
             "makeInOut2Float: " +
             "(ArrayTest.ArrayOps.check2Float(array) == true)");

      }

      /*
       * inout null 2D double complex array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut2Dcomplex using null array");

	  sidl.DoubleComplex.Array2 array = new sidl.DoubleComplex.Array2();
	  ArrayTest.ArrayOps.makeInOut2Dcomplex(array, TEST_DIM1, TEST_DIM2);
	  check(PASS,
		(ArrayTest.ArrayOps.check2Dcomplex(array) == true),
		"makeInOut2Dcomplex: " +
		"(ArrayTest.ArrayOps.check2Dcomplex(array) == true)");

      }

      /*
       * inout null 2D float complex array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut2Fcomplex using null array");

	  sidl.FloatComplex.Array2 array = new sidl.FloatComplex.Array2();
	  ArrayTest.ArrayOps.makeInOut2Fcomplex(array, TEST_DIM1, TEST_DIM2);
	  check(PASS,
		(ArrayTest.ArrayOps.check2Fcomplex(array) == true),
		"makeInOut2Fcomplex: " +
		"(ArrayTest.ArrayOps.check2Fcomplex(array) == true)");

      }

      /*
       * inout null 3D integer array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut3Int using null array");

	  sidl.Integer.Array3 array = new sidl.Integer.Array3();
	  ArrayTest.ArrayOps.makeInOut3Int(array);
	  check(PASS,
		(ArrayTest.ArrayOps.check3Int(array) == true),
		"makeInOut3Int: " +
		"(ArrayTest.ArrayOps.check3Int(array) == true)");
	  
      }

      /*
       * inout null 4D integer array test
       */

      if (true) {
	  //check(XFAIL, false, "makeInOut4Int using null array");

	  sidl.Integer.Array4 array = new sidl.Integer.Array4();
	  ArrayTest.ArrayOps.makeInOut4Int(array);
	  check(PASS,
		(ArrayTest.ArrayOps.check4Int(array) == true),
		"makeInOut4Int: " +
		"(ArrayTest.ArrayOps.check4Int(array) == true)");
	  
      }

      /*
       * inout null 5D integer array test
       */

      if (true) {

	  sidl.Integer.Array5 array = new sidl.Integer.Array5();
	  ArrayTest.ArrayOps.makeInOut5Int(array);
	  check(PASS,
		(ArrayTest.ArrayOps.check5Int(array) == true),
		"makeInOut5Int: " +
		"(ArrayTest.ArrayOps.check5Int(array) == true)");
	  
      }
      /*
       * inout null 6D integer array test
       */

      if (true) {

	  sidl.Integer.Array6 array = new sidl.Integer.Array6();
	  ArrayTest.ArrayOps.makeInOut6Int(array);
	  check(PASS,
		(ArrayTest.ArrayOps.check6Int(array) == true),
		"makeInOut6Int: " +
		"(ArrayTest.ArrayOps.check6Int(array) == true)");
	  
      }

      /*
       * inout null 7D integer array test
       */

      if (true) {

	  sidl.Integer.Array7 array = new sidl.Integer.Array7();
	  ArrayTest.ArrayOps.makeInOut7Int(array);
	  check(PASS,
		(ArrayTest.ArrayOps.check7Int(array) == true),
		"makeInOut7Int: " +
		"(ArrayTest.ArrayOps.check7Int(array) == true)");
	  
      }

      /*
       * Output final test results
       */

      System.out.println("TEST_RESULT " + s_results[s_result]);

      Runtime.getRuntime().exit(0); /* workaround for Linux JVM 1.3.1 bug */
    /*
     * Catch any unexpected exceptions and return a test failure
     */
    } catch (Throwable ex) {
      System.out.println("TEST_RESULT FAIL");
      System.out.println(ex.toString());
      System.exit(1);
    }
  }
}

